## Get-Uniprot: A Simple Python CLI for Grabbing Protein Sequences. 🧬

### Prerequisites:
- Python >=3.6  

### Quickstart:
```
pip install get-uniprot
```
### Usage:
Usage: uniprot [OPTIONS]

Options:
  -q, --query TEXT     Name of protein.
  -o, --organism TEXT  Name of organism.
  -f, --file           Output sequence to .fasta file.
  --help               Show this message and exit.
